@@ -1,5 +1,18 @@
 #!/bin/bash -ex
 
+NAME=$1
+
+if [ "$NAME" == "" ]
+then
+    echo "Usage: runner-init.sh <name>"
+    exit 1
+fi
+
+if [ "$IMAGE" == "" ]
+then
+    IMAGE=ldapjdk-runner
+fi
+
 docker run \
     --name=${NAME} \
     --hostname=${HOSTNAME} \
@@ -7,7 +20,6 @@ docker run \
     --privileged \
     --tmpfs /tmp \
     --tmpfs /run \
-    -v /sys/fs/cgroup:/sys/fs/cgroup:ro \
     -v ${GITHUB_WORKSPACE}:${SHARED} \
     -i \
     ${IMAGE}
